.. _qualification_test_report_rf6_multisuite:

============================================
Qualification Test Report for rf6_multisuite
============================================

The log file that contains details about the executed test cases can be found `here <log.html>`_.

.. contents:: `Contents`
    :depth: 2
    :local:


Test Reports
============

.. item:: REPORT_SWQTEST-CLOSED_LOOP_MOTOR_CONTROL Test report for SWQTEST-CLOSED_LOOP_MOTOR_CONTROL
    :passes: SWQTEST-CLOSED_LOOP_MOTOR_CONTROL
    :ext_robotframeworklog: log.html:s1-t1

    Test result: Pass

    closed loop motor control extra content

.. item:: REPORT_SWQTEST-CLOSED_LOOP_SLEW_RATE Test report for SWQTEST-CLOSED_LOOP_SLEW_RATE
    :passes: SWQTEST-CLOSED_LOOP_SLEW_RATE
    :ext_robotframeworklog: log.html:s1-t2

    Test result: Pass

.. item:: REPORT_SWQTEST-BLOCKED_MOTOR_BLOCKED Test report for SWQTEST-BLOCKED_MOTOR_BLOCKED
    :passes: SWQTEST-BLOCKED_MOTOR_BLOCKED
    :ext_robotframeworklog: log.html:s1-t3

    Test result: Pass

    blocked motor blocked extra content

.. item:: REPORT_SWQTEST-MOTOR_START_WITH_FIXED_BRAKING_TIME Test report for SWQTEST-MOTOR_START_WITH_FIXED_BRAKING_TIME
    :passes: SWQTEST-MOTOR_START_WITH_FIXED_BRAKING_TIME
    :ext_robotframeworklog: log.html:s1-t4

    Test result: Pass

.. item:: REPORT_SWQTEST-MOTOR_STOP_WITH_FIXED_BRAKING_TIME Test report for SWQTEST-MOTOR_STOP_WITH_FIXED_BRAKING_TIME
    :passes: SWQTEST-MOTOR_STOP_WITH_FIXED_BRAKING_TIME
    :ext_robotframeworklog: log.html:s1-t5

    Test result: Pass

    motor stop with fixed braking time extra content

.. item:: REPORT_SWQTEST-OPEN_LOOP_MOTOR_CONTROL Test report for SWQTEST-OPEN_LOOP_MOTOR_CONTROL
    :passes: SWQTEST-OPEN_LOOP_MOTOR_CONTROL
    :ext_robotframeworklog: log.html:s1-t6

    Test result: Pass

.. item:: REPORT_SWQTEST-OPEN_LOOP_SLEW_RATE Test report for SWQTEST-OPEN_LOOP_SLEW_RATE
    :passes: SWQTEST-OPEN_LOOP_SLEW_RATE
    :ext_robotframeworklog: log.html:s1-t7

    Test result: Pass

Traceability Matrix
===================

The below table traces the test report to test cases.

.. item-matrix:: Linking these qualification test reports to qualification test cases
    :source: REPORT_SWQTEST-
    :target: SWQTEST-
    :sourcetitle: Qualification test report
    :targettitle: Qualification test specification
    :type: fails passes skipped
    :stats:
    :group: top
    :nocaptions:
